import React, { Component } from 'react';
import { StyleSheet, View, Text, Animated, Image, ScrollView } from 'react-native';
import PropTypes from 'prop-types';

export default class RNSA extends Component {
  constructor(props) {
    super(props);
    this.headerScrollDistance = props.headerMaxHeight - props.headerMinHeight;
    this.state = {
      scrollY: new Animated.Value(0),
    };
  }

  _renderScrollViewContent() {
    const data = Array.from({length: 30});
    return (
      <View style={{marginTop: this.props.headerMaxHeight,}}>
        {this.props.contentArea()}
      </View>
    );
  }

  render() {
    const headerHeight = this.state.scrollY.interpolate({
      inputRange: [0, this.headerScrollDistance],
      outputRange: [this.props.headerMaxHeight, this.props.headerMinHeight],
      extrapolate: 'clamp',
    });
    return (
      <View style={[styles.container, this.props.containerStyle]}>
        <ScrollView
          style={styles.fill}
          scrollEventThrottle={16}
          onScroll={Animated.event(
            [{nativeEvent: {contentOffset: {y: this.state.scrollY}}}]
          )}
        >
          {this._renderScrollViewContent()}
        </ScrollView>
        <Animated.View style={[styles.header, {height: headerHeight}]}>
          {this.props.headerArea()}
        </Animated.View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  fill: {
    flex: 1,
  },
  row: {
    height: 40,
    margin: 16,
    backgroundColor: '#D3D3D3',
    alignItems: 'center',
    justifyContent: 'center',
  },
  header: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    backgroundColor: '#03A9F4',
    overflow: 'hidden',
  },
  bar: {
    marginTop: 28,
    height: 32,
    alignItems: 'center',
    justifyContent: 'center',
  },
  title: {
    backgroundColor: 'transparent',
    color: 'white',
    fontSize: 18,
  },
});

RNSA.propTypes = {
  containerStyle: PropTypes.any,
  headerArea: PropTypes.func,
  contentArea: PropTypes.func,
  headerMaxHeight: PropTypes.number,
  headerMinHeight: PropTypes.number,
};

RNSA.defaultProps = {
  containerStyle: {},
  headerArea: () => {},
  contentArea: () => {},
  headerMaxHeight: 300,
  headerMinHeight: 50,
};